@@ -18,7 +18,6 @@ module SiSU_Viz
     def path_rel
       '../'
     end
-  end
   #% url
     def url_home
       'http://www.gutenberg.net'
@@ -52,27 +51,24 @@ module SiSU_Viz
     end
     #% credits
     def credits_splash
-      %{<table summary="credits" align="center"bgcolor="#ffffff"><tr><td><font color="black"><center><a href="http://www.gutenberg.net/"><img border="0" align="center" src="../_sisu/image_local/gutenberg_icon.png" alt="Gutenberg Project"><br />Courtesy of The Gutenberg Project</a><br />#{widget_sisu}</center></font></td></tr></table>}
+      %{<table summary="credits" align="center"bgcolor="#ffffff"><tr><td><font color="black"><center><a href="http://www.gutenberg.net/"><img border="0" align="center" src="../_sisu/image_local/gutenberg_icon.png" alt="Gutenberg Project"><br />Courtesy of The Gutenberg Project</a></center></font></td></tr></table>}
     end
   end
   class TeX
     def header_center
-	    "\\chead{\\href{#{@vz.url_home}}{www.gutenberg.net}}"
+      "\\chead{\\href{#{@vz.url_home}}{www.gutenberg.net}}"
     end
     def home_url
-	    "\\href{#{@vz.url_home}}{www.gutenberg.net}"
+      "\\href{#{@vz.url_home}}{www.gutenberg.net}"
     end
     def home
-	    "\\href{#{@vz.url_home}}{Gutenberg Project}"
+      "\\href{#{@vz.url_home}}{Gutenberg Project}"
     end
     def owner_chapter
       "Document owner details"
     end
-    def stmp
-	    "\\copyright Ralph Amissah, licence GPL \\\\\n www.jus.uio.no/sisu/"
-    end
   end
-  class DAL
+  class Inserts
     def insert1
 <<CONTENTS
 
@@ -216,4 +212,4 @@ CONTENTS
     end
   end
 end
-
+__END__
