@@ -60,8 +60,10 @@
 
 =end
 module SiSU_Assemble
+  require 'fileutils'
   require "#{SiSU_lib}/sysenv"
   class Remote_image
+    include FileUtils
     def initialize
       @env=SiSU_Env::Info_env.new
     end
