@@ -581,7 +581,9 @@ WOK
     color: #000077;
   }
   li.doc {
-    background: url(../image/bullet_doc.png) no-repeat 0 0;
+    background: url(../image/bullet_09.png) no-repeat 0px 6px;
+    /* background: url(../image/bullet_doc.png) no-repeat 0 0; */
+    /* background: url(../../_sisu/image/bullet_09.png) no-repeat 0px 6px; */
     padding-left: 16px;
     margin-left: 10px;
     margin-top: 0px;
@@ -603,6 +605,7 @@ WOK
     text-align: left;
   }
   li.refcenter {
+    background: url(../image/bullet_09.png) no-repeat 0px 6px;
     /* background: url(../image/bullet_doc.png) no-repeat 0 0; */
     background: none;
     padding-left: 20px;
@@ -614,7 +617,8 @@ WOK
     text-align: center;
   }
   li.refbold {
-    background: url(../image/bullet_doc.png) no-repeat 0 0;
+    background: url(../image/bullet_09.png) no-repeat 0px 6px;
+    /* background: url(../image/bullet_doc.png) no-repeat 0 0; */
     /* padding-left: 0px; */
     padding-left: 16px;
     margin-left: 0;
