@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -60,8 +64,8 @@ module SiSU_DB_create
   class Create < SiSU_DB_columns::Column_size
     require "#{SiSU_lib}/sysenv"
     @@dl=nil
-    def initialize(opt,conn='',sql_type='pg')
-      @opt,@conn,@sql_type=opt,conn,sql_type
+    def initialize(opt,conn,file,sql_type='pg')
+      @opt,@conn,@file,@sql_type=opt,conn,file,sql_type
       @cX=SiSU_Screen::Ansi.new(@opt.cmd).cX
       @comment=Comment.new(@sql_type)
       @@dl ||=SiSU_Env::Info_env.new.digest.length
@@ -82,7 +86,9 @@ module SiSU_DB_create
     end
     def output_dir?
       dir=SiSU_Env::Info_env.new('')
-      if @opt.cmd =~/d/; dir.path.webserv_stub_ensure
+      if @opt.cmd =~/d/
+        #p dir.path.webserv_stub_ensure.inspect
+        dir.path.webserv_stub_ensure
       end
     end
     def create_table
@@ -95,7 +101,7 @@ module SiSU_DB_create
         } unless @opt.cmd =~/q/
         @conn.execute(%{
           CREATE TABLE metadata (
-            tid               INT4 PRIMARY KEY,
+            tid               BIGINT PRIMARY KEY,
             title             VARCHAR(#{lt_title}) NULL,
             subtitle          VARCHAR(#{lt_subtitle}) NULL,
             creator           VARCHAR(#{lt_creator}) NULL,
@@ -160,8 +166,8 @@ module SiSU_DB_create
         } unless @opt.cmd =~/q/
         @conn.execute(%{
           CREATE TABLE documents (
-            lid             INT4 PRIMARY KEY,
-            metadata_tid    INT4 REFERENCES metadata,
+            lid             BIGINT PRIMARY KEY,
+            metadata_tid    BIGINT REFERENCES metadata,
             ocn             SMALLINT,
             ocnd            VARCHAR(6),
             ocns            VARCHAR(6),
@@ -190,14 +196,14 @@ module SiSU_DB_create
       end
       def endnotes
         print %{
-          to be populated from documents files
+          to be populated from document files
           create tables endnotes
           data import through ruby transfer
         } unless @opt.cmd =~/q/
         @conn.execute(%{
           CREATE TABLE endnotes (
-            nid             INT4 PRIMARY KEY,
-            document_lid    INT4 REFERENCES documents,
+            nid             BIGINT PRIMARY KEY,
+            document_lid    BIGINT REFERENCES documents,
             nr              SMALLINT,
             clean           TEXT NULL,
             body            TEXT NULL,
@@ -205,21 +211,21 @@ module SiSU_DB_create
             ocnd            VARCHAR(6),
             ocns            VARCHAR(6),
             digest_clean    CHAR(#{@@dl}),
-            metadata_tid    INT4 REFERENCES metadata
+            metadata_tid    BIGINT REFERENCES metadata
           );
           #{@comment.endnotes}
         })
       end
       def endnotes_asterisk
         print %{
-          to be populated from documents files
+          to be populated from document files
           create tables endnotes_asterisk
           data import through ruby transfer
         } unless @opt.cmd =~/q/
         @conn.execute(%{
           CREATE TABLE endnotes_asterisk (
-            nid             INT4 PRIMARY KEY,
-            document_lid    INT4 REFERENCES documents,
+            nid             BIGINT PRIMARY KEY,
+            document_lid    BIGINT REFERENCES documents,
             nr              SMALLINT,
             clean           TEXT NULL,
             body            TEXT NULL,
@@ -227,21 +233,21 @@ module SiSU_DB_create
             ocnd            VARCHAR(6),
             ocns            VARCHAR(6),
             digest_clean    CHAR(#{@@dl}),
-            metadata_tid    INT4 REFERENCES metadata
+            metadata_tid    BIGINT REFERENCES metadata
           );
           #{@comment.endnotes_asterisk}
         })
       end
       def endnotes_plus
         print %{
-          to be populated from documents files
+          to be populated from document files
           create tables endnotes_plus
           data import through ruby transfer
         } unless @opt.cmd =~/q/
         @conn.execute(%{
           CREATE TABLE endnotes_plus (
-            nid             INT4 PRIMARY KEY,
-            document_lid    INT4 REFERENCES documents,
+            nid             BIGINT PRIMARY KEY,
+            document_lid    BIGINT REFERENCES documents,
             nr              SMALLINT,
             clean           TEXT NULL,
             body            TEXT NULL,
@@ -249,7 +255,7 @@ module SiSU_DB_create
             ocnd            VARCHAR(6),
             ocns            VARCHAR(6),
             digest_clean    CHAR(#{@@dl}),
-            metadata_tid    INT4 REFERENCES metadata
+            metadata_tid    BIGINT REFERENCES metadata
           );
           #{@comment.endnotes_plus}
         })
@@ -263,7 +269,7 @@ module SiSU_DB_create
         } unless @opt.cmd =~/q/
         @conn.execute(%{
           CREATE TABLE urls (
-            metadata_tid    INT4 REFERENCES metadata,
+            metadata_tid    BIGINT REFERENCES metadata,
             plaintext       varchar(512),
             html_toc        varchar(512),
             html_doc        varchar(512),
