@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -57,14 +61,12 @@
 =end
 module SiSU_DB_index
   class Index                                           # create documents Indexes def initialize(opt,conn='',sql_type='')
-    def initialize(opt,conn='',sql_type='')
-      @opt,@conn,@sql_type=opt,conn,sql_type
+    def initialize(opt,conn,file,sql_type='')
+      @opt,@conn,@file,@sql_type=opt,conn,file,sql_type
     end
     def create_indexes                                                           # check added from pg not tested
       def base
-        print '
-          create documents common indexes
-        ' unless @opt.cmd =~/q/
+        print "\n          create documents common indexes\n" unless @opt.cmd =~/q/
         @conn.execute('
           CREATE INDEX object_nr ON documents(ocn);
           CREATE INDEX digest_clean ON documents(digest_clean);
@@ -88,9 +90,7 @@ module SiSU_DB_index
         ') unless @opt.cmd =~/q/
       end
       def text
-        print '
-          create documents text indexes
-        ' unless @opt.cmd =~/q/
+        print "\n          create documents text indexes\n" unless @opt.cmd =~/q/
         @conn.execute('
           CREATE INDEX clean ON documents(clean);
           CREATE INDEX endnote ON endnotes(clean);
