@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -59,14 +63,31 @@ module SiSU_DB_select
   class Case
     def initialize(opt,conn='',sql_type='pg')
       @opt,@conn,@sql_type=opt,conn,sql_type
+#@conn.execute("BEGIN;")
       #@sdb=Create.new(@conn)
-      @sdb=SiSU_DB_DBI::Create.new(@opt,@conn,@sql_type)
-      @index=SiSU_DB_DBI::Index.new(@opt,@conn,@sql_type)
-      @sdb_no=SiSU_DB_DBI::Drop.new(@opt,@conn,@sql_type)
-      @sdb_import=SiSU_DB_DBI::Import.new(@opt,@conn,@sql_type) if @opt.mod.inspect =~/update|import/
-      @remove=SiSU_DB_DBI::Remove.new(@opt,@conn) if @opt.mod.inspect =~/update|remove/
+      @file=sql_maintenance_file
+      @sdb=SiSU_DB_DBI::Create.new(@opt,@conn,@file,@sql_type)
+      @sdb_index=SiSU_DB_DBI::Index.new(@opt,@conn,@file,@sql_type)
+      @sdb_no=SiSU_DB_DBI::Drop.new(@opt,@conn,@file,@sql_type)
+      @sdb_import=SiSU_DB_DBI::Import.new(@opt,@conn,@file,@sql_type) if @opt.mod.inspect =~/update|import/
+      @sdb_remove_doc=SiSU_DB_DBI::Remove.new(@opt,@conn,@file) if @opt.mod.inspect =~/update|remove/
       @db=SiSU_Env::Info_db.new
     end
+    def sql_maintenance_file
+      file=if @opt.inspect =~/M/
+        x=if @opt.fns and not @opt.fns.empty?
+          @env=SiSU_Env::Info_env.new(@opt.fns) if @opt.fns
+          puts "\n#{@env.path.sqlite}/#{@opt.fns}.sql"
+          @db=SiSU_Env::Info_db.new
+          @job="sqlite3 #{@db.sqlite.db} < #{@env.path.sqlite}/#{@opt.fns}.sql"
+          File.new("#{@env.path.sqlite}/#{@opt.fns}.sql",'w+')
+        elsif @opt.fns and @opt.fns.inspect =~/create/; nil #sort variations later
+        else nil
+        end
+      else nil
+      end
+      file
+    end
     def cases
       @opt.mod.each do |mod|
         case mod
@@ -80,13 +101,14 @@ module SiSU_DB_select
           @sdb.output_dir?
           #@sdb.create_db
           begin
+          #@sdb.create_db
           @sdb.create_table.metadata
           @sdb.create_table.documents
           @sdb.create_table.endnotes
           @sdb.create_table.endnotes_asterisk
           @sdb.create_table.endnotes_plus
           @sdb.create_table.urls
-          @index.create_indexes
+          @sdb_index.create_indexes
           rescue;  SiSU_Errors::Info_error.new($!,$@,'-D').error; @sdb.output_dir?
           end
         when /^--createtable(s)?$/
@@ -98,7 +120,7 @@ module SiSU_DB_select
           @sdb.create_table.endnotes_asterisk
           @sdb.create_table.endnotes_plus
           @sdb.create_table.urls
-          @index.create_indexes
+          @sdb_index.create_indexes
           rescue; @sdb.output_dir?
           end
         when /^--recreate$/
@@ -111,7 +133,7 @@ module SiSU_DB_select
           @sdb.create_table.endnotes_asterisk
           @sdb.create_table.endnotes_plus
           @sdb.create_table.urls
-          @index.create_indexes
+          @sdb_index.create_indexes
           rescue; @sdb.output_dir?
           end
         when /^--cr(eate)?lex$/
@@ -135,14 +157,14 @@ module SiSU_DB_select
           end
           tell.puts_grey if @opt.cmd =~/v/
         when /^--remove$/
-          @remove.remove
+          @sdb_remove_doc.remove
         when /^--update$/
-          @remove.remove
+          @sdb_remove_doc.remove
           @sdb_import.marshal_load
           tell=SiSU_Screen::Ansi.new(@opt.cmd,"pgaccess or psql #{@db.psql.db} database?")
           tell.puts_grey if @opt.cmd =~/v/
         when /^--index$/
-          @index.create_indexes
+          @sdb_index.create_indexes
         when /^droptable(s)?$/
           @sdb_no.drop.tables
         when /^--dropindex(es)?$/
@@ -156,6 +178,12 @@ module SiSU_DB_select
           help.summary
           help.commands
         end
+        if @opt.cmd =~/M/
+          #@conn.commit
+          #@conn.disconnect
+          puts @job
+          #system(@job)
+        end
       end
       begin
       @conn.commit if @sql_type =~/sqlite/
