@@ -150,11 +150,14 @@ module SiSU_Digest_view
         data.each do |para|
           x=nil
           y,para_endnotes=[],[]
-          if para =~/<~(\d+);((?:\w|[0-6]:)\d+);(\w\d+)><([0-9a-f]{#@dl}):([0-9a-f]{#@dl})>/
+          if para =~/#{Mx[:id_o]}~(\d+);((?:\w|[0-6]:)\d+);(\w\d+)#{Mx[:id_c]}#{Mx[:id_o]}([0-9a-f]{#@dl}):([0-9a-f]{#@dl})#{Mx[:id_c]}/
             ocn,h1,h2,d_clean,d_all=$1,$2,$3,$4,$5
             @ocn=ocn unless ocn.to_i == 0
-            if para=~/~\{[\d*+]+.+?<[0-9a-f]{#@dl}>\}~/
-              para_endnotes << para.scan(/~[{\[]([\d*+]+).+?<([0-9a-f]{#@dl})>[}\]]~/)
+            para.gsub!(/#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,'<b>\1</b>')
+            para.gsub!(/#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}/,'<i>\1</i>')
+            para.gsub!(/#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}/,'<u>\1</u>')
+            if para=~/#{Mx[:en_a_o]}[\d*+]+.+?#{Mx[:id_o]}[0-9a-f]{#@dl}#{Mx[:id_c]}#{Mx[:en_a_c]}/
+              para_endnotes << para.scan(/(?:#{Mx[:en_a_o]}|#{Mx[:en_b_o]})([\d*+]+).+?#{Mx[:id_o]}([0-9a-f]{#@dl})#{Mx[:id_c]}(?:#{Mx[:en_a_c]}|#{Mx[:en_b_c]})/)
             end
             ima=[]
             if para !~/^%+\s/ \
@@ -163,21 +166,21 @@ module SiSU_Digest_view
             else image=nil
             end
             x=case para
-            when /^0~title/
+            when /^#{Mx[:meta_o]}title#{Mx[:meta_c]}/
               "\n" + '  '*0 +'@' + '  '*9
-            when /^0~subtitle/
+            when /^#{Mx[:meta_o]}subtitle#{Mx[:meta_c]}/
               "\n" + '  '*1 +'@' + '  '*8
-            when /^1~/
+            when /^#{Mx[:lv_o]}1:/
               "\n" + '  '*2 +':A ' + '  '*6 +'- ' + ocn + ' '*(10-ocn.length) + d_clean + ' ' + d_all
-            when /^2~/
+            when /^#{Mx[:lv_o]}2:/
               "\n" + '  '*3 +':B ' + '  '*5 +'- ' + ocn + ' '*(10-ocn.length) + d_clean + ' ' + d_all
-            when /^3~/
+            when /^#{Mx[:lv_o]}3:/
               "\n" + '  '*4 +':C ' + '  '*4 +'- ' + ocn + ' '*(10-ocn.length) + d_clean + ' ' + d_all
-            when /^4~/
+            when /^#{Mx[:lv_o]}4:/
               "\n" + '  '*5 +'1' + '  '*4 +'- ' + ocn + ' '*(10-ocn.length) + d_clean + ' ' + d_all
-            when /^5~/
+            when /^#{Mx[:lv_o]}5:/
               "\n" + '  '*6 +'2' + '  '*3 +'- ' + ocn + ' '*(10-ocn.length) + d_clean + ' ' + d_all
-            when /^6~/
+            when /^#{Mx[:lv_o]}6:/
               "\n" + '  '*7 +'3' + '  '*2 +'- ' + ocn + ' '*(10-ocn.length) + d_clean + ' ' + d_all
             else
               if para =~/MD5\(\S+?\.sst\)=\s*<u>([0-9a-f]{#@dl})<\/u>/                                        #watch
@@ -248,20 +251,20 @@ module SiSU_Digest_view
                 m_ruby_version=rgx_txt(@tr.ruby_version)
                 case para
                 when /#{m_dc_title}: /
-                  @t=/#{m_dc_title}: (.+?)<~\d;(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{#@dl}:[0-9a-f]{#@dl}>/.match(para)[1].gsub(/<\/?u>/,'').strip
+                  @t=/#{m_dc_title}: (.+?)#{Mx[:id_o]}~\d;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#@dl}:[0-9a-f]{#@dl}#{Mx[:id_c]}/.match(para)[1].gsub(/<\/?u>/,'').strip
                 when /#{m_creator}: /
-                  @c=/#{m_creator}: (.+?)<~\d;(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{#@dl}:[0-9a-f]{#@dl}>/.match(para)[1].gsub(/<\/?u>/,'').strip
+                  @c=/#{m_creator}: (.+?)#{Mx[:id_o]}~\d;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#@dl}:[0-9a-f]{#@dl}#{Mx[:id_c]}/.match(para)[1].gsub(/<\/?u>/,'').strip
                 when /#{m_sourcefile_digest}.+?<u>/                                        #watch
                   dgst_extra="\n" + ' '*21 +'source' +' '*4 + @md.dgst[1] + ' '*34 + @md.fns
                 when /Skin_Digest: /
                   dgst_extra="\n" + ' '*21 + 'skin' +' '*6 + @md.dgst_skin[1] + ' '*34 + /(skin_\S+?\.rb)/.match(@md.dgst_skin[0])[1]
                 when /#{m_sisu_version}: /
-                  @v=/#{m_sisu_version}: (.+?)<~\d;(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{#@dl}:[0-9a-f]{#@dl}>/.match(para)[1].gsub(/<\/?u>/,'').strip
+                  @v=/#{m_sisu_version}: (.+?)#{Mx[:id_o]}~\d;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#@dl}:[0-9a-f]{#@dl}#{Mx[:id_c]}/.match(para)[1].gsub(/<\/?u>/,'').strip
                 when /#{m_last_generated}: /
-                  @g=/#{m_last_generated}: (.+?)<~\d;(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{#@dl}:[0-9a-f]{#@dl}>/.match(para)[1].gsub(/<\/?u>/,'').strip
+                  @g=/#{m_last_generated}: (.+?)#{Mx[:id_o]}~\d;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#@dl}:[0-9a-f]{#@dl}#{Mx[:id_c]}/.match(para)[1].gsub(/<\/?u>/,'').strip
  #                                                   'doc last generated'
                 when /#{m_ruby_version}: /
-                  @r=/#{m_ruby_version}: (.+?)<~\d;(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{#@dl}:[0-9a-f]{#@dl}>/.match(para)[1].gsub(/<\/?u>/,'').strip
+                  @r=/#{m_ruby_version}: (.+?)#{Mx[:id_o]}~\d;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#@dl}:[0-9a-f]{#@dl}#{Mx[:id_c]}/.match(para)[1].gsub(/<\/?u>/,'').strip
                 end
                 dgst_extra ||=''
                 "\n" + prefix +' - ' + ocn + ' '*(10-ocn.length) + d_clean + ' ' + d_all + dgst_extra + "\n"
@@ -306,27 +309,27 @@ module SiSU_Digest_view
         ocn,endnotes=nil,nil
         data.each do |para|
           x=case para
-          when /^0~/; l[0] +=1
-            if para =~/^0~title/; '' #'  '*0 +'@ == headers' + "\n" + '  '*0 +'headings:'
+          when /^#{Mx[:meta_o]}/; l[0] +=1
+            if para =~/^#{Mx[:meta_o]}title#{Mx[:meta_c]}/; '' #'  '*0 +'@ == headers' + "\n" + '  '*0 +'headings:'
             end
-          when /^1~/; l[1] +=1
+          when /^#{Mx[:lv_o]}1:/; l[1] +=1
             '  '*0 +':A'
-          when /^2~/; l[2] +=1
+          when /^#{Mx[:lv_o]}2:/; l[2] +=1
             '  '*1 +':B'
-          when /^3~/; l[3] +=1
+          when /^#{Mx[:lv_o]}3:/; l[3] +=1
             '  '*2 +':C'
-          when /^4~/; l[4] +=1
+          when /^#{Mx[:lv_o]}4:/; l[4] +=1
             '  '*3 +'1'
-          when /^5~/; l[5] +=1
+          when /^#{Mx[:lv_o]}5:/; l[5] +=1
             '  '*4 +'2'
-          when /^6~/; l[6] +=1
+          when /^#{Mx[:lv_o]}6:/; l[6] +=1
             '  '*5 +'3'
           else nil
           end
-          if para =~/<~(\d+);(?:\w|[0-6]:)\d+;\w\d+><[0-9a-f]{#@dl}:[0-9a-f]{#@dl}>/
+          if para =~/#{Mx[:id_o]}~(\d+);(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#@dl}:[0-9a-f]{#@dl}#{Mx[:id_c]}/
             ocn=$1 unless $1.to_i == 0
           end
-          if para =~/~[{\[]([\d*+]+).+?<[0-9a-f]{#@dl}>[}\]]~/
+          if para =~/(?:#{Mx[:en_a_o]}|#{Mx[:en_b_o]})([\d*+]+).+?#{Mx[:id_o]}[0-9a-f]{#@dl}#{Mx[:id_c]}(?:#{Mx[:en_a_c]}|#{Mx[:en_b_c]})/
             endnotes=$1 unless $1.to_i == 0
           end
           dal_structure_tree("#{x}\n") if x and not x.empty?
