@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -98,7 +102,7 @@ module SiSU_HTML_promo
           end
           ads_array
         end
-        adverts(ads)
+        adverts(ads.join)
       #else no_adverts
       end
     end
@@ -189,7 +193,7 @@ module SiSU_HTML_promo
               links_a << %{<p class="pane_link"><a href="#{url_}">#{x['title']}#{subtitle}</a></p>\n}
             end
           end
-          links_a.to_s
+          links_a.join
         else ''
         end
       end
@@ -379,7 +383,7 @@ WOK
         @ad[:promo_list][category].keys.each do |type|
           @ad[:promo_list][category][type].each do |i|
             if i
-              id=i.to_s =~/^\d/ ? "id_#{i.to_s.strip}" : i.to_s.strip
+              id=i.inspect =~/^\d/ ? "id_#{i.to_s.strip}" : i.to_s.strip #watch remove .to_s ?
               gbp=usd=euro=nil
               if defined? @ad[:promo][type][id] \
               and not @ad[:promo][type][id].nil?
@@ -392,7 +396,7 @@ WOK
         tell=SiSU_Screen::Ansi.new(@md.cmd,"category not found: #{category}")
         tell.warn unless @md.cmd =~/q/
       end
-      adverts.to_s
+      adverts.join
     end
     def advert_extract_all #extracts all products from list (which is broken down into categories)
       adverts=[]
