@@ -419,8 +419,8 @@ p "here #{__FILE__} #{__LINE__}" if @opt =~/M/
         end
         if @opt.cmd =~/[hHz]/; op('html','html')               #% -h -H -z html css
         end
-        if @opt.cmd =~/A/; op('air','air')         #% #-A
-        end
+        #if @opt.cmd =~/A/; op('air','air')         #% #-A
+        #end
         if @opt.cmd =~/a/; op('plaintext','plaintext')         #% -a #-A -f -e -E plaintext -a creates ms-dos type; -A creates unix type, plaintext file
         end
         if @opt.cmd =~/g/; op('wikispeak','wikispeak')         #% -g wiki
