@@ -174,47 +174,97 @@ module SiSU_Manifest
       def output_tests
         if FileTest.file?("#@base_path/#{@md.fn[:toc]}")==true
           img='<img border="0" height="18" width="15" src="../_sisu/image_sys/b_toc.png" alt="TOC linked" /> '
-          id,file='table of contents (for segmented HTML text)',@md.fn[:toc]
+          id,file='HTML, table of contents (for segmented text)',@md.fn[:toc]
           summarize(id,file,img)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:doc]}")==true
           img='<img border="0" height="15" width="15" src="../_sisu/image_sys/b_doc.png" alt="Full Text" /> '
-          id,file='full length document (HTML)',@md.fn[:doc]
+          id,file='HTML, full length document',@md.fn[:doc]
           summarize(id,file,img)
         end
-        if FileTest.file?("#@base_path/#{@md.fn[:pdf_p]}")==true
+        #if FileTest.file?("#@base_path/#{@md.fn[:pdf_p]}")==true
+        #  img='<img border="0" height="18" width="15" src="../_sisu/image_sys/b_pdf.png" alt="PDF portrait" /> '
+        #  id,file="full length document (PDF portrait&nbsp;/ vertical - recommended for printing), size #{@md.papersize_array[0]}",@md.fn[:pdf_p]
+        #  summarize(id,file,img)
+        #end
+        #if FileTest.file?("#@base_path/#{@md.fn[:pdf_l]}")==true
+        #  img='<img border="0" height="15" width="18" src="../_sisu/image_sys/b_pdf.png" alt="PDF landscape" /> '
+        #  id,file="full length document (PDF landscape&nbsp;/ horizontal - recommended for screen viewing), size #{@md.papersize_array[0]}",@md.fn[:pdf_l]
+        #  summarize(id,file,img)
+        #end
+        if FileTest.file?("#@base_path/#{@md.fn[:pdf_p_letter]}")==true
           img='<img border="0" height="18" width="15" src="../_sisu/image_sys/b_pdf.png" alt="PDF portrait" /> '
-          id,file='full length document (PDF portrait&nbsp;/ vertical - recommended for printing)',@md.fn[:pdf_p]
+          id,file="PDF, U.S. letter size, portrait/vertical document (recommended for printing)",@md.fn[:pdf_p_letter]
           summarize(id,file,img)
         end
-        if FileTest.file?("#@base_path/#{@md.fn[:pdf_l]}")==true
+        if FileTest.file?("#@base_path/#{@md.fn[:pdf_l_letter]}")==true
           img='<img border="0" height="15" width="18" src="../_sisu/image_sys/b_pdf.png" alt="PDF landscape" /> '
-          id,file='full length document (PDF landscape&nbsp;/ horizontal - recommended for screen viewing)',@md.fn[:pdf_l]
+          id,file="PDF, U.S. letter size, landscape/horizontal document (recommended for screen viewing)",@md.fn[:pdf_l_letter]
+          summarize(id,file,img)
+        end
+        if FileTest.file?("#@base_path/#{@md.fn[:pdf_p_a4]}")==true
+          img='<img border="0" height="18" width="15" src="../_sisu/image_sys/b_pdf.png" alt="PDF portrait" /> '
+          id,file="PDF, A4 size, portrait/vertical document (recommended for printing)",@md.fn[:pdf_p_a4]
+          summarize(id,file,img)
+        end
+        if FileTest.file?("#@base_path/#{@md.fn[:pdf_l_a4]}")==true
+          img='<img border="0" height="15" width="18" src="../_sisu/image_sys/b_pdf.png" alt="PDF landscape" /> '
+          id,file="PDF, A4 size, landscape/horizontal document (recommended for screen viewing)",@md.fn[:pdf_l_a4]
+          summarize(id,file,img)
+        end
+        if FileTest.file?("#@base_path/#{@md.fn[:pdf_p_a5]}")==true
+          img='<img border="0" height="18" width="15" src="../_sisu/image_sys/b_pdf.png" alt="PDF portrait" /> '
+          id,file="PDF, A5 (book) size, portrait/vertical document (recommended for printing)",@md.fn[:pdf_p_a5]
+          summarize(id,file,img)
+        end
+        if FileTest.file?("#@base_path/#{@md.fn[:pdf_l_a5]}")==true
+          img='<img border="0" height="15" width="18" src="../_sisu/image_sys/b_pdf.png" alt="PDF landscape" /> '
+          id,file="PDF, A5 (book) size, landscape/horizontal document (recommended for screen viewing)",@md.fn[:pdf_l_a5]
+          summarize(id,file,img)
+        end
+        if FileTest.file?("#@base_path/#{@md.fn[:pdf_p_b5]}")==true
+          img='<img border="0" height="18" width="15" src="../_sisu/image_sys/b_pdf.png" alt="PDF portrait" /> '
+          id,file="PDF, B5 (book) size, portrait/vertical document (recommended for printing)",@md.fn[:pdf_p_b5]
+          summarize(id,file,img)
+        end
+        if FileTest.file?("#@base_path/#{@md.fn[:pdf_l_b5]}")==true
+          img='<img border="0" height="15" width="18" src="../_sisu/image_sys/b_pdf.png" alt="PDF landscape" /> '
+          id,file="PDF, B5 (book) size, landscape/horizontal document (recommended for screen viewing)",@md.fn[:pdf_l_b5]
+          summarize(id,file,img)
+        end
+        if FileTest.file?("#@base_path/#{@md.fn[:pdf_p_legal]}")==true
+          img='<img border="0" height="18" width="15" src="../_sisu/image_sys/b_pdf.png" alt="PDF portrait" /> '
+          id,file="PDF, U.S. legal size, portrait/vertical document (recommended for printing)",@md.fn[:pdf_p_legal]
+          summarize(id,file,img)
+        end
+        if FileTest.file?("#@base_path/#{@md.fn[:pdf_l_legal]}")==true
+          img='<img border="0" height="15" width="18" src="../_sisu/image_sys/b_pdf.png" alt="PDF landscape" /> '
+          id,file="PDF, U.S. legal size, landscape/horizontal document (recommended for screen viewing)",@md.fn[:pdf_l_legal]
           summarize(id,file,img)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:odf]}")==true
           img='<img border="0" height="18" width="18" src="../_sisu/image_sys/b_odf.png" alt="ODF/ODT" /> '
-          id,file='full length document (ODF:ODT - Open Document Format)',@md.fn[:odf]
+          id,file='ODF:ODT (Open Document Format)',@md.fn[:odf]
           summarize(id,file,img)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:xhtml]}")==true
-          id,file='full length document (XHTML)',@md.fn[:xhtml]
+          id,file='XHTML',@md.fn[:xhtml]
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:sax]}")==true
-          id,file='full length document (XML SAX)',@md.fn[:sax]
+          id,file='XML SAX',@md.fn[:sax]
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:dom]}")==true
-          id,file='full length document (XML DOM)',@md.fn[:dom]
+          id,file='XML DOM',@md.fn[:dom]
           summarize(id,file)
         end
         if FileTest.file?("#@base_path/#{@md.fn[:plain]}")==true
-        if    @md.cmd =~/a/; id,file='full length document (plaintext Unix (UTF-8) with footnotes)',@md.fn[:plain]
-        elsif @md.cmd =~/e/; id,file='full length document (plaintext Unix (UTF-8) with endnotes)',@md.fn[:plain]
-        elsif @md.cmd =~/A/; id,file='full length document (plaintext dos (UTF-8) with footnotes)',@md.fn[:plain]
-        elsif @md.cmd =~/E/; id,file='full length document (plaintext dos (UTF-8) with endnotes)',@md.fn[:plain]
-        else                id,file='full length document (plaintext (UTF-8))',@md.fn[:plain]
+        if    @md.cmd =~/a/; id,file='Plaintext (Unix (UTF-8) with footnotes)',@md.fn[:plain]
+        elsif @md.cmd =~/e/; id,file='Plaintext (Unix (UTF-8) with endnotes)',@md.fn[:plain]
+        elsif @md.cmd =~/A/; id,file='Plaintext (dos (UTF-8) with footnotes)',@md.fn[:plain]
+        elsif @md.cmd =~/E/; id,file='Plaintext (dos (UTF-8) with endnotes)',@md.fn[:plain]
+        else                id,file='Plaintext (UTF-8)',@md.fn[:plain]
         end
           summarize(id,file)
         end
