@@ -81,10 +81,10 @@ module Format
     def initialize(one,two,three)
       one.gsub!(/\.(html|pdf|php)/,'') if one =~/\.\.\/\S+/
       @one,@two,@three=one,two,three
-      rgx=/^[1-6-]~/
+      rgx=/^#{Mx[:lv_o]}[1-6-]:/
       @one.gsub!(rgx,'') if @one =~rgx
       @dp=@@dp ||=SiSU_Env::Info_env.new.digest.pattern
-      rgx=/~\{[\d*+]+\s+(.+?)<#@dp>\}~/
+      rgx=/#{Mx[:en_a_o]}[\d*+]+\s+(.+?)#{Mx[:id_o]}#@dp#{Mx[:id_c]}#{Mx[:en_a_c]}/
       @one.gsub!(rgx,'\1') if @one =~rgx
       @link,@linkname=one,two
       @vz=SiSU_Env::Get_init.instance.skin
