@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -76,7 +80,7 @@ module SiSU_Doc
       @zipfile=if @opt.fns =~/\.ssm\.sst$/; @opt.fns.gsub(/(?:\~\S{2,3})?\.ssm\.sst$/,'.ssm')
       else @opt.fns.gsub(/(?:\~\S{2,3})?(\.sst)$/,'\1')
       end
-      File.mkpath(pod_path) unless FileTest.directory?(pod_path)
+      mkdir_p(pod_path) unless FileTest.directory?(pod_path)
       rm_rf("#{@env.path.processing}sisupod/*") if FileTest.directory?("#{@env.path.processing}sisupod")
     end
     def read
@@ -257,7 +261,7 @@ module SiSU_Doc
       end #NB not all possibilies met, revisit, also in case of composite file may wish to add README
     end
     def sisupod_7zip #look at later
-      File.mkpath(@local_path) unless FileTest.directory?(@local_path)
+      mkdir_p(@local_path) unless FileTest.directory?(@local_path)
       system(%{
         cd #{@env.path.processing}
         echo "SiSU sisupod #{@ver[:version]}" > sisu_zip.txt
@@ -272,7 +276,7 @@ module SiSU_Doc
       tell.blue_tab unless @opt.cmd =~/q/
     end
     def sisupod_zip
-      File.mkpath(@local_path) unless FileTest.directory?(@local_path)
+      mkdir_p(@local_path) unless FileTest.directory?(@local_path)
       system(%{
         cd #{@env.path.processing}
         echo "SiSU sisupod #{@ver[:version]}" > sisu_zip.txt
