@@ -1,3 +1,4 @@
+# coding: utf-8
 =begin
 
  * Name: SiSU
@@ -7,14 +8,14 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
    Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   2007, 2008 Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -31,9 +32,12 @@
 
    If you have Internet connection, the latest version of the GPL should be
    available at these locations:
-   <http://www.fsf.org/licenses/gpl.html>
-   <http://www.gnu.org/copyleft/gpl.html>
-   <http://www.jus.uio.no/sisu/gpl.fsf>
+   <http://www.fsf.org/licensing/licenses/gpl.html>
+   <http://www.gnu.org/licenses/gpl.html>
+
+   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
+   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>
 
  * SiSU uses:
    * Standard SiSU markup syntax,
@@ -70,7 +74,7 @@ def talent(termsheet,flag)
   @@info=termsheet.gsub(/(.+?)\.termsheet\.rb/,'../facility_data/\1.html')
   @env=SiSU_Env::Info_env.new
   @dir_fd="#{@env.path.output}/facility_data"
-  File.mkpath(@dir_fd) unless FileTest.directory?(@dir_fd)==true
+  mkdir_p(@dir_fd) unless FileTest.directory?(@dir_fd)==true
   html_output=[]
   case termsheet
   when /.+?\.(termsheet)\.rb$/
