@@ -177,8 +177,8 @@ WOK
       end
       def markup(para,type='')
         para.strip!
-        para=para.gsub(/^[1-9]~(?:\S+)?\s+/,'')
-        para=para.gsub(/<~(\d+);(?:\d:\d+|\S\d+);\S\d+><#@dp:#@dp>/,'[(\1)]')
+        para=para.gsub(/^#{Mx[:lv_o]}[1-9]:\S*?#{Mx[:lv_c]}\s*/,'')
+        para=para.gsub(/#{Mx[:id_o]}~(\d+);(?:\d:\d+|\S\d+);\S\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}/,'[(\1)]')
         para=@trans.markup_fictionbook(para)
         para=if type.empty?; "<p>#{para}</p>"
         else "<#{type}><p>#{para}</p></#{type}>"
@@ -288,7 +288,7 @@ WOK
         @ds=[]
         c=0
         data.each do |para|
-          rgx_headers=/<~(\d+);((?:\w|[0-6]:)\d+);(\w\d+)>/
+          rgx_headers=/#{Mx[:id_o]}~(\d+);((?:\w|[0-6]:)\d+);(\w\d+)#{Mx[:id_c]}/
           if para =~rgx_headers
             x=(rgx_headers).match(para)
             if x[3] =~/^[hum]\d+/
