@@ -292,7 +292,7 @@ WOK
         @paranum=/(\d+)/m.match(txt[2])[1]
         @headname=''
         #if txt[2]=~/\d+/
-        m=/\d~(\S+)/m.match(format)
+        m=/#{Mx[:lv_o]}\d:(\S+?)#{Mx[:lv_c]}/m.match(format)
         headname=m[1] if m
         @headname=%{<a name="h#{headname}"></a>} unless headname.nil?
         @p_num=SiSU_XML_format::Paragraph_number.new(@md,@paranum)
@@ -301,7 +301,7 @@ WOK
       rgx=/^[1-6-]~{1,2}/ #watch
       link=txt[0].gsub(rgx,'') if @one =~rgx
       @dp=@@dp ||=SiSU_Env::Info_env.new.digest.pattern
-      rgx=/~\{\d+\s+(.+?)<#@dp>\}~/
+      rgx=/~\{\d+\s+(.+?)#{Mx[:id_o]}#@dp#{Mx[:id_c]}\}~/
       link=txt[0].gsub(rgx,'\1') if txt[0] =~rgx
       @link,@linkname=link,txt[1]
       @vz=SiSU_Env::Get_init.instance.skin
