@@ -185,8 +185,8 @@ module SiSU_XML_scaffold
         @ds=[]
         c=0
         data.each do |para|
-          if para =~/<~\d+;(?:\w|[0-6]:)\d+;\w\d+>/
-            x=(/<~(\d+);((?:\w|[0-6]:)\d+);(\w\d+)>/).match(para)
+          if para =~/#{Mx[:id_o]}~\d+;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}/
+            x=(/#{Mx[:id_o]}~(\d+);((?:\w|[0-6]:)\d+);(\w\d+)#{Mx[:id_c]}/).match(para)
             if x[3] =~/^[hu]\d+/
               @ds[c]={}
               @ds[c][:ocn]=x[1]
